<?php if (!defined('BASEPATH')) exit('No direct script access allowed');

/**
 * Плагин csv_banner для MaxSite CMS
 * http://max-3000.com/
 * Вывод из файла CSV в виджет
 */


# функция автоподключения плагина
function csv_banner_autoload($args = array())
{
	# регистрируем виджет
	mso_register_widget('csv_banner_widget', t('Список товаров'));	
	if( is_type('admin') )
	{
		// хук на админку
		mso_hook_add('admin_init','csv_banner_admin_init');
	}
}


# функция выполняется при деинсталяции плагина
function csv_banner_uninstall($args = array())
{
	mso_delete_option('csv_banner', 'plugins' ); // удалим созданные опции
	mso_remove_allow('csv_banner_edit'); // удалим созданные разрешения
	mso_delete_option_mask('csv_banner_', 'plugins' ); // удалим созданные опции

	return $args;
}




function csv_banner_activate($args = array())
{
	mso_create_allow('csv_banner_edit',  t('Админ-доступ к настройкам', 'admin'));
	return $args;
}

function csv_banner_admin_init($args = array())
{
	if ( mso_check_allow('csv_banner_edit') )
	{
		mso_admin_menu_add('plugins', 'csv_banner', t('csv_banner', __FILE__));
		mso_admin_url_hook ('csv_banner', 'csv_banner_admin_page');
	}
	return $args;
}


function csv_banner_admin_page($args = array())
{
	# выносим админские функции отдельно в файл
	if ( !mso_check_allow('csv_banner_edit') )
	{
		echo t('Доступ запрещен', 'plugins');
		return $args;
	}
	# выносим админские функции отдельно в файл
	mso_hook_add_dinamic( 'mso_admin_header', ' return $args . "' . t('csv_banner', __FILE__) . '"; ' );
	mso_hook_add_dinamic( 'admin_title', ' return "' . t('csv_banner', __FILE__) . ' - " . $args; ' );
	require(getinfo('plugins_dir') . 'csv_banner/admin.php');
}


// виджет

# функция, которая берет настройки из опций виджетов
function csv_banner_widget($num = 1)
{
	$widget = 'csv_banner_widget_' . $num; // имя для опций = виджет + номер
	$options = mso_get_option($widget, 'plugins', array() ); // получаем опции

	// заменим заголовок, чтобы был в  h2 class="box"
	if ( isset($options['header']) and $options['header'] ) 
		$options['header'] = mso_get_val('widget_header_start', '<div class="mso-widget-header"><span>') . $options['header'] . mso_get_val('widget_header_end', '</span></div>');
	else 
		$options['header'] = '';

	return csv_banner_widget_custom($options, $num);
}


# форма настройки виджета
# имя функции = виджет_form
function csv_banner_widget_form($num = 1)
{
	$widget = 'csv_banner_widget_' . $num; // имя для формы и опций = виджет + номер

	// получаем опции
	$options = mso_get_option($widget, 'plugins', array());

	if ( !isset($options['header']) )	$options['header'] = t('Товары');
	if ( !isset($options['cache_time']) )	$options['cache_time'] = 0;
	if ( !isset($options['count']) )	$options['count'] = 4;
	if ( !isset($options['template']) ) 	$options['template'] = 
		'<div class="pad10"><p><a href="#URL#" target="_blank"><img class="center w70" src="#IMG#"></a></p><p class="t90 mar5-tb "><a href="#URL#" target="_blank">#DESC#</a></p></div>';

	// вывод самой формы
	$CI = & get_instance();
	
	$CI->load->helper('form');
	
	$form = mso_widget_create_form(t('Заголовок'), form_input( array( 'name'=>$widget . 'header', 'value'=>$options['header'] ) ), '');
		
	$form .= mso_widget_create_form(t('Время кеширования'), form_input( array( 'name'=>$widget . 'cache_time', 'value'=>$options['cache_time'] ) ), '');

	$form .= mso_widget_create_form(t('Количество'), form_input( array( 'name'=>$widget . 'count', 'value'=>$options['count'] ) ), '');

	$form .= mso_widget_create_form(t('Шаблон вывода'), form_textarea( array( 'name'=>$widget . 'template', 'value'=>$options['template'], 'rows' => '5')), htmlspecialchars('<div class="pad10"><p><a href="#URL#" target="_blank"><img class="center w70" src="#IMG#"></a></p><p class="t90 mar5-tb "><a href="#URL#" target="_blank">#DESC#</a></p></div>'));
	
	return $form;
}

# сюда приходят POST из формы настройки виджета
# имя функции = виджет_update
function csv_banner_widget_update($num = 1)
{
	$widget = 'csv_banner_widget_' . $num; // имя для опций = виджет + номер

	// получаем опции
	$options = $newoptions = mso_get_option($widget, 'plugins', array());

	# обрабатываем POST
	$newoptions['header'] = mso_widget_get_post($widget . 'header');
	$newoptions['cache_time'] = (int) mso_widget_get_post($widget . 'cache_time');
	$newoptions['count'] = (int) mso_widget_get_post($widget . 'count');
	$newoptions['template'] = mso_widget_get_post($widget . 'template');

	if ( $options != $newoptions )
		mso_add_option($widget, $newoptions, 'plugins' );
}


function csv_banner_widget_custom($arg = array(), $num = 1)
{
	if ( !isset($arg['header']) )		$arg['header'] = mso_get_val('widget_header_start', '<div class="mso-widget-header"><span>') . t('Последние записи') . mso_get_val('widget_header_end', '</span></div>');
	if ( !isset($arg['cache_time']) )	$arg['cache_time'] = 0;
	if ( !isset($arg['count']) )	$arg['count'] = 0;
	if ( !isset($arg['template']) )		$arg['template'] = 
		'<div class="pad10"><p><a href="#URL#" target="_blank"><img class="center w70" src="#IMG#"></a></p><p class="t90 mar5-tb "><a href="#URL#" target="_blank">#DESC#</a></p></div>';

	$out = '';
	
	$cache_key = 'csv_banner_widget-' . serialize($arg) . '-' . $num;
	
	if ($arg['cache_time'] > 0 and $out = mso_get_cache($cache_key) )
	{
		return $out; # да есть в кэше
	}
	
	$out = $arg['header'];
    $options_key_list = 'csv_banner_list';
	$list = mso_get_option($options_key_list, 'plugins', array());
	$cur_list = array_rand($list, $arg['count'] );
	foreach ($cur_list as $item)
	{
		$out .= str_replace(array('#URL#','#IMG#', '#DESC#'), array($list[$item]['Promotion Url'], $list[$item]['Image Url'], $list[$item]['Product Desc']), $arg['template']);
	}		
	
	if ($arg['cache_time'] > 0) mso_add_cache($cache_key, $out, $arg['cache_time'] * 60);
	return $out;
}

# end of file

